@@ -23,7 +23,7 @@ class BigIntegerTests(TestCase):
         int_smallest = BigInteger.objects.create(big_integer=-9223372036854775808)
         self.assertEqual(int_smallest.big_integer, -9223372036854775808)
         self.assertLess(int_smallest.big_integer, int_biggest.big_integer)
-        with self.assertRaises(ValueError):
+        with self.assertRaises(Exception):
             BigInteger.objects.create(big_integer=18446744073709551616)
-        with self.assertRaises(ValueError):
+        with self.assertRaises(Exception):
             BigInteger.objects.create(big_integer=-9223372036854776840)
